
import React, { Component } from 'react';
import { DatePicker, Form } from 'antd';
const { RangePicker } = DatePicker;
import moment from 'moment';

class Item extends Component {
  getOutputValue = {
    date: (date) => {
      let start = moment(date).format('YYYY-MM-DD 00:00:00');
      let end = moment(date).format('YYYY-MM-DD 23:59:59');
      return [start, end];
    },
    week: (date) => {
      const day = moment(date).day();
      let start = moment(date).add(-(day), 'day').format('YYYY-MM-DD 00:00:00');
      let end = moment(date).add(6 - day, 'day').format('YYYY-MM-DD 23:59:59');
      return [start, end];
    },
    month: (date) => {
      let start = moment(date).format('YYYY-MM-01 00:00:00');
      let end = moment(date);
      end = end.format(`YYYY-MM-${end.daysInMonth()} 23:59:59`);
      return [start, end];
    },
    quarter: (date) => {
      let start = moment(date);
      start = start.add(-(start.month()%3), 'month');
      start = start.format(`YYYY-MM-01 00:00:00`);
      let end = moment(date);
      end = end.add(2 - end.month()%3, 'month');
      end = end.format(`YYYY-MM-${end.daysInMonth()} 23:59:59`);
      return [start, end];
    },
    year: (date) => {
      let start = moment(date).format('YYYY-01-01 00:00:00');
      let end = moment(date).format('YYYY-12-31 23:59:59');
      return [start, end];
    },
    rangeDate: (date = []) => {
      let start = moment(date[0]).format('YYYY-MM-DD 00:00:00');
      let end = moment(date[1]).format('YYYY-MM-DD 23:59:59');
      return [start, end];
    },
    rangeDateTime: (date = []) => {
      let start = moment(date[0]).format('YYYY-MM-DD HH:mm:ss');
      let end = moment(date[1]).format('YYYY-MM-DD HH:mm:ss');
      return [start, end];
    },
    rangeWeek: (date = []) => {
      let start = moment(date[0]).add(-3, 'day').format('YYYY-MM-DD 00:00:00');
      let end = moment(date[1]).add(3, 'day').format('YYYY-MM-DD 23:59:59');
      return [start, end];
    },
    rangeMonth: (date = []) => {
      let start = moment(date[0]).format('YYYY-MM-01 00:00:00');
      let end = moment(date[1]);
      end = end.format(`YYYY-MM-${end.daysInMonth()} 23:59:59`);
      return [start, end];
    },
    rangeQuarter: (date = []) => {
      let start = moment(date[0]);
      start = start.add(-(2 - start.month()%3), 'month');
      start = start.format(`YYYY-MM-01 00:00:00`);
      let end = moment(date[1]);
      end = end.add(2 - end.month()%3, 'month');
      end = end.format(`YYYY-MM-${end.daysInMonth()} 23:59:59`);
      return [start, end];
    },
    rangeYear: (date = []) => {
      let start = moment(date[0]).format('YYYY-01-01 00:00:00');
      let end = moment(date[1]).format('YYYY-12-31 23:59:59');
      return [start, end];
    },
  }

  getValue = () => {
    const {param = {}, picker} = this.props;
    let value = param.value || [];
    if(['week', 'month', 'quarter', 'year'].indexOf(picker) >= 0 || !picker) {
      value = value[0] ? moment(value[0]) : ''
    }
    else if(value.length === 2){
      value = [moment(value[0]), moment(value[1])];
    }
    return value;
  }

  onChange = (date, dateString) => {
    const {param = {}, picker} = this.props;
    if(param.onChange && typeof param.onChange === 'function') {
      const value = this.getOutputValue[picker || 'date'](date);
      param.onChange(value || '');
    }
  }

  pickerProps = {
    rangeDate: {},
    rangeDateTime: {
      showTime: true,
    },
    rangeWeek: {
      picker: 'week'
    },
    rangeMonth: {
      picker: 'month'
    },
    rangeQuarter: {
      picker: 'quarter'
    },
    rangeYear: {
      picker: 'year'
    }
  };

  renderContent = () => {
    const {
      label,
      param = {},
      className,
      style,
      picker,

      placeholder,
      autoFocus,
      size,
      disabled,
      minDate,
      maxDate,
      locale
    } = this.props;
    const currProps = {
      ...(label ? {} : {
        className: className || '',
        style: style || {},
        value: this.getValue(),
        onChange: this.onChange,
      }),
      
      ...(locale ? {
        locale,
      } : {}),

      placeholder: placeholder,
      autoFocus: autoFocus,
      size: size,
      disabled: disabled,
      disabledDate: (current) => {
        let isDisabled = false;
        if(minDate || minDate === 0) {
          isDisabled = current < moment().add((-Number(`${minDate}`)) - 1, 'day');
        }
        if((maxDate || maxDate === 0) && !isDisabled) {
          isDisabled = current > moment().add(Number(`${maxDate}`), 'day');
        }
        return isDisabled;
      },
    }
    if(['week', 'month', 'quarter', 'year'].indexOf(picker) >= 0) {
      currProps.picker = picker;
    }
    if('showTime' === picker) {
      currProps.showTime = true;
    }
    
    if(['rangeDate', 'rangeDateTime', 'rangeWeek', 'rangeMonth', 'rangeQuarter', 'rangeYear'].indexOf(picker) >= 0) {
      const pickerProp = this.pickerProps[picker] || {};
      
      return <RangePicker {...currProps} {...pickerProp}/>
    }

    return <DatePicker {...currProps}/>;
  }
  
  render() {
    const {
      label,
      param = {},
      className,
      style,
    } = this.props;

    const content = this.renderContent();

    return label ? <Form.Item
      className={className}
      style={style}
      {...(param.name ? {
        name: param.name,
      } : {})}
      label={label}
      initialValue={param.value ? moment(param.value) : ''}
      onChange={this.onChange}
      rules={param.rules}
    >
    {content}
  </Form.Item> : content
  }
}
export default Item;
 
 
 